alwaysRenderBlock property
Controls whether the element must be rendered as a block.
Default: true if onRenderBlock is set, false otherwise.
If an element has multiple build ops and one of them require block rendering, it will be rendered as block.
Implementation
final bool? alwaysRenderBlock;